@page versioning  Version Numbering


Numbering Scheme
================

The current POV-Ray version numbering scheme is designed to comply with the format and precedence rules of
[Semantic Versioning v2.0.0](http://semver.org/spec/v2.0.0.html). However, it differs notably in the semantics of the
third field of the version number (referred to as _patch version_ in the Semantic Versioning standard), as well as
in a few special uses of the _pre-release_ field.

POV-Ray **source code** version numbers have the form `X.Y.Z`[-`PRE`], where:

  - `X` is the major version number, and is intended to indicate radical changes, such as the planned redesign of the
    scene description language (SDL).
  - `Y` is a minor version number, and is intended to indicate significant architectural or feature changes; for
    instance the addition of support for distributed rendering will certainly go along with an increase of the minor
    version number.
  - `Z` is a sub-minor version number, and is primarily intended to indicate addition of, or changes in, minor features,
    so that they can be tested for from the SDL.
  - `PRE`, if present, is a pre-release identifier comprised of alphanumeric and numeric fields separated by dots
    (`.`), indicating that the version is a forerunner to, but may still differ in functionality from, what will
    ultimately become the official release `X.Y.Z`, and that the version should not be used in a production
    environment. It typically has one of the following forms:
      - `PHASE.ID`, with `PHASE` being one of `alpha`, `beta` or `rc`, indicates that the version is part of the
        main line of development in the respective phase of the development cycle.
      - `x.FEATURE.ID` indicates that the version is part of a side line of development, uniquely identified by the
        alphanumeric moniker `FEATURE`, which may ultimately contribute to the main line, but in its current state is
        deemed unfit to be included for one reason or another.
      .
    In both cases `ID` is a numeric value uniquely distinguishing the pre-release in question from other pre-releases
    of that same phase or side line.

@note
    Due to the semantics of the `#version` directive and `version` pseudo-variable, both the `Y` and `Z` portions of
    the version number are restricted to single digits.

POV-Ray **build** version numbers have the form `X.Y.Z`[-`PREB`][`+BUILD`], where:

  - `X.Y.Z` matches the corresponding portion of the source code version.
  - `PREB` generally matches the `PRE` portion of the source code version, except that it always contains an
    additional `unofficial` entry (separated from the `PRE` portion by a dot if applicable) unless the POV-Ray dev
    team has officially authorized the build for public distribution.
  - `BUILD`, if present, is an alphanumeric identifier uniquely distinguishing a particular build from other builds
    based on the very same source code version. For example, automated builds generated by the AppVeyor service on
    behalf of the POV-Ray team carry build identifiers of the form `avN`, where `N` is a running numeric value.


What To Change
==============

When updating a version number, the following files need to be changed accordingly:

  - `unix/VERSION`
  - `source/base/version.h`

@warning
    When updating the minor or major version number, a host of other files need to be changed as well.


Automatic Version Numbering
===========================

The directory `tools/git/hooks` contains scripts intended to (among other things) help with version numbering when using
Git; to benefit from them, copy them to the `.git/hooks` directory in your local Git workspace. Whenever you perform a
commit, they will automatically take care of the following:

  - Verify that `unix/VERSION` and the various version number variants in `source/base/version.h` match.
  - Update the `ID` portion of pre-release versions whenever any files in one of the following directory sub-trees have
    been staged for commit: `source`, `vfe`, `platform`, `mac`, `unix`, `windows` or `libraries`. The new value of the
    `ID` portion will be the number of minutes elapsed since 2000-01-01 00:00 UTC.
